@@ -5,6 +5,7 @@ import json
 import shlex
 import os
 import sys
+import requests
 from pathlib import Path
 from packaging.version import Version
 
@@ -12,7 +13,6 @@ import textwrap
 from typing import Any, Dict, List, Tuple
 import click
 import re
-import requests
 from concurrent.futures import Future, ThreadPoolExecutor, as_completed
 import cloup
 from cloup.constraints import If, IsSet, accept_none, require_one
@@ -36,32 +36,48 @@ SCHEMA_DEFINITION_FILE: str = os.path.join(SCHEMA_DIR, "_definitions.json")
 RESOURCES_MAPPING_FILE: str = os.path.join(SCHEMA_DIR, "__resources-mappings.json")
 
 
-def _is_kind_and_namespaced(client: str, _data: Dict[str, Any]) -> Dict[str, Any]:
+def _is_kind_and_namespaced(client: str, _key: str, _data: Dict[str, Any]) -> Dict[str, Any]:
     x_kubernetes_group_version_kind = _data["x-kubernetes-group-version-kind"][0]
     _kind = x_kubernetes_group_version_kind["kind"]
     _group = x_kubernetes_group_version_kind.get("group")
     _version = x_kubernetes_group_version_kind.get("version")
     _group_and_version = f"{_group}/{_version}" if _group else _version
 
-    if run_command(command=shlex.split(f"{client} explain {_kind}"), check=False, log_errors=False)[0]:
-        namespaced = (
+    not_resource_dict = {"is_kind": False, "kind": _key}
+
+    # if explain command failed, this is not a resource
+    if not run_command(command=shlex.split(f"{client} explain {_kind}"), check=False, log_errors=False)[0]:
+        return not_resource_dict
+
+    # check if this as a valid version for the resource.
+    api_resources_base_cmd = f"bash -c '{client} api-resources"
+
+    if run_command(
+        command=shlex.split(f"{api_resources_base_cmd} | grep -w {_kind} | grep {_group_and_version}'"),
+        check=False,
+        log_errors=False,
+    )[0]:
+        # Check if the resource if namespaced.
+        _data["namespaced"] = (
             run_command(
                 command=shlex.split(
-                    f"bash -c '{client} api-resources --namespaced | grep -w {_kind} | grep {_group_and_version} | wc -l'"
+                    f"{api_resources_base_cmd} --namespaced | grep -w {_kind} | grep {_group_and_version} | wc -l'"
                 ),
                 check=False,
+                log_errors=False,
             )[1].strip()
             == "1"
         )
-        _data["namespaced"] = namespaced
-        return {"is_kind": True, "kind": _kind, "data": _data}
+        return {"is_kind": True, "kind": _key, "data": _data}
 
-    return {"is_kind": False, "kind": _kind}
+    return not_resource_dict
 
 
 def map_kind_to_namespaced(client: str):
     not_kind_file: str = os.path.join(SCHEMA_DIR, "__not-kind.txt")
 
+    resources_mapping = read_resources_mapping_file()
+
     if os.path.isfile(not_kind_file):
         with open(not_kind_file) as fd:
             not_kind_list = fd.read().split("\n")
@@ -71,37 +87,45 @@ def map_kind_to_namespaced(client: str):
     with open(SCHEMA_DEFINITION_FILE) as fd:
         _definitions_json_data = json.load(fd)
 
-    resources_mapping: Dict[Any, List[Any]] = {}
-
     _kind_data_futures: List[Future] = []
     with ThreadPoolExecutor() as executor:
-        for _data in _definitions_json_data["definitions"].values():
+        for _key, _data in _definitions_json_data["definitions"].items():
             _group_version_kind = _data.get("x-kubernetes-group-version-kind")
             if not _group_version_kind:
                 continue
 
-            if _group_version_kind[0]["kind"] in not_kind_list:
+            if _key in not_kind_list:
                 continue
 
-            _kind_data_futures.append(executor.submit(_is_kind_and_namespaced, client=client, _data=_data))
+            _kind_data_futures.append(executor.submit(_is_kind_and_namespaced, client=client, _key=_key, _data=_data))
 
+    _temp_resources_mappings: Dict[Any, Any] = {}
     for res in as_completed(_kind_data_futures):
         _res = res.result()
+        # _res["kind"] is group.version.kind, set only kind as key in the final dict
+        kind_key = _res["kind"].rsplit(".", 1)[-1].lower()
+
         if _res["is_kind"]:
-            resources_mapping.setdefault(_res["kind"].lower(), []).append(_res["data"])
+            _temp_resources_mappings.setdefault(kind_key, []).append(_res["data"])
         else:
             not_kind_list.append(_res["kind"])
 
+    # Update the resources mapping dict with the one that we filled to avoid duplication in the lists
+    resources_mapping.update(_temp_resources_mappings)
+
     with open(RESOURCES_MAPPING_FILE, "w") as fd:
-        json.dump(resources_mapping, fd)
+        json.dump(resources_mapping, fd, indent=4)
 
     with open(not_kind_file, "w") as fd:
         fd.writelines("\n".join(not_kind_list))
 
 
 def read_resources_mapping_file() -> Dict[Any, Any]:
-    with open(RESOURCES_MAPPING_FILE) as fd:
-        return json.load(fd)
+    try:
+        with open(RESOURCES_MAPPING_FILE) as fd:
+            return json.load(fd)
+    except (FileNotFoundError, json.JSONDecodeError):
+        return {}
 
 
 def get_server_version(client: str):
@@ -142,7 +166,7 @@ def update_kind_schema():
 
     if not run_command(command=shlex.split("which openapi2jsonschema"), check=False, log_errors=False)[0]:
         LOGGER.error(
-            f"{openapi2jsonschema_str}not found. Install it using `pipx install --python python3.9 openapi2jsonschema`"
+            f"{openapi2jsonschema_str} not found. Install it using `pipx install --python python3.9 openapi2jsonschema`"
         )
         sys.exit(1)
 
